@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw(Exporter);
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ Tickit::DSL - domain-specific language for Tickit terminal apps
 
 =head1 VERSION
 
-Version 0.013
+Version 0.014
 
 =head1 SYNOPSIS
 
@@ -78,6 +78,8 @@ mainly intended for prototyping:
 
 =cut
 
+# spot the odd one out
+use Tickit::Console;
 use Tickit::Widget::Border;
 use Tickit::Widget::Box;
 use Tickit::Widget::Button;
@@ -133,6 +135,7 @@ our @EXPORT = our @EXPORT_OK = qw(
 	static entry checkbox button
 	radiogroup radiobutton
 	scroller scroller_text scroller_richtext scrollbox
+	console
 	tabbed
 	tree table
 	placeholder placegrid decoration
@@ -636,6 +639,36 @@ sub scroller_richtext {
 	apply_widget($w);
 }
 
+=head2 console
+
+Console widget. Current just supports creating the
+console and setting an on_line callback:
+
+ my $con = console {
+  warn "Had a line: @_";
+ };
+ $con->add_tab(
+  name => 'test',
+  on_line => sub { warn "test line: @_" }
+ );
+
+although a future version may provide C< console_tab >
+as a helper function for adding tabs to an existing
+console.
+
+=cut
+
+sub console(&@) {
+	my %args = (on_line => @_);
+	my %parent_args = map {; $_ => delete $args{'parent:' . $_} } map /^parent:(.*)/ ? $1 : (), keys %args;
+	my $w = Tickit::Console->new(
+		%args
+	);
+	local @WIDGET_ARGS = (@WIDGET_ARGS, %parent_args);
+	apply_widget($w);
+	$w
+}
+
 =head1 FUNCTIONS - Miscellaneous container
 
 These act as containers.
@@ -1278,7 +1311,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
